/// <reference types="node" />
import { NextMiddleware, NextRequest, NextResponse } from "next/server";
import { PageEvent, PublicUrl, UserProperties, CollectOpts } from "./index";
import { NextApiHandler, NextApiRequest, NextApiResponse } from "next";
import { IncomingMessage } from "http";
export declare type EventCollector = {
    nextApiHandler<U extends PageEvent = PageEvent, P extends UserProperties = UserProperties>(req: NextApiRequest, res: NextApiResponse, opts: NextApiHandlerOpts): Promise<any>;
    nextJsPageMiddleware<U extends PageEvent = PageEvent, P extends UserProperties = UserProperties>(req: NextRequest, res: Response, props?: NextMiddlewareOpts): Promise<NextResponse>;
};
/**
 * A facade function that gets header from NextRequest or NextApiRequest.
 *
 * In case of multiple headers with the same name, values will be separated by `,`
 */
export declare function getHeader(req: NextRequest | NextApiRequest, h: string): string | undefined;
export declare function getAllHeaders(req: NextRequest | NextApiRequest): Record<string, string>;
/**
 * A facade function that gets cookie val from NextRequest or NextApiRequest
 */
export declare function getCookie(req: NextRequest | NextApiRequest, name: string): string | undefined;
export declare function parsePublicUrlNodeApi(req: IncomingMessage): PublicUrl;
export declare type DynamicOption<Req, Res, T> = ((req: Req, res: Res, originalEvent: any) => T) | T | undefined;
export declare function eventCollector(opts: CollectOpts): EventCollector;
export declare type NextMiddlewareOpts<U extends PageEvent = PageEvent & any, P extends UserProperties = UserProperties & any> = {
    middleware?: NextMiddleware;
    cookieName?: DynamicOption<NextRequest, NextResponse, string>;
    cookieDomain?: DynamicOption<NextRequest, NextResponse, string>;
    extend?: DynamicOption<NextRequest, NextResponse, U>;
    /**
     * If true, system next requests starting from /_next/ will be logged too, otherwise they are
     * all skipped
     */
    processSystemRequests?: boolean;
};
export declare type NextApiHandlerOpts<U extends PageEvent = PageEvent & any, P extends UserProperties = UserProperties & any> = {
    cookieName?: DynamicOption<NextApiRequest, NextApiResponse, string>;
    cookieDomain?: DynamicOption<NextApiRequest, NextApiResponse, string>;
    extend?: DynamicOption<NextApiRequest, NextApiResponse, U>;
};
export declare type NextCollectOpts = CollectOpts & NextMiddlewareOpts & NextApiHandlerOpts;
export declare function collectEvents(opts: CollectOpts & NextMiddlewareOpts): NextMiddleware;
export declare function collectApiHandler(opts: CollectOpts & NextApiHandlerOpts): NextApiHandler;
/**
 * @deprecated use collectEvents instead
 */
export declare const nextEventsCollectApi: typeof collectApiHandler;
